import { localize } from '../../nls.js';
const minute = 60;
const hour = minute * 60;
const day = hour * 24;
const week = day * 7;
const month = day * 30;
const year = day * 365;
function fromNow(date, appendAgoLabel, useFullTimeWords, disallowNow) {
    if (typeof date !== 'number') {
        date = date.getTime();
    }
    const seconds = Math.round((( (new Date())).getTime() - date) / 1000);
    if (seconds < -30) {
        return ( localize(
            703,
            'in {0}',
            fromNow(( (new Date())).getTime() + seconds * 1000, false)
        ));
    }
    if (!disallowNow && seconds < 30) {
        return ( localize(704, 'now'));
    }
    let value;
    if (seconds < minute) {
        value = seconds;
        if (appendAgoLabel) {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(705, '{0} second ago', value))
                    : ( localize(706, '{0} sec ago', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(707, '{0} seconds ago', value))
                    : ( localize(708, '{0} secs ago', value));
            }
        }
        else {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(709, '{0} second', value))
                    : ( localize(710, '{0} sec', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(711, '{0} seconds', value))
                    : ( localize(712, '{0} secs', value));
            }
        }
    }
    if (seconds < hour) {
        value = Math.floor(seconds / minute);
        if (appendAgoLabel) {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(713, '{0} minute ago', value))
                    : ( localize(714, '{0} min ago', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(715, '{0} minutes ago', value))
                    : ( localize(716, '{0} mins ago', value));
            }
        }
        else {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(717, '{0} minute', value))
                    : ( localize(718, '{0} min', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(719, '{0} minutes', value))
                    : ( localize(720, '{0} mins', value));
            }
        }
    }
    if (seconds < day) {
        value = Math.floor(seconds / hour);
        if (appendAgoLabel) {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(721, '{0} hour ago', value))
                    : ( localize(722, '{0} hr ago', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(723, '{0} hours ago', value))
                    : ( localize(724, '{0} hrs ago', value));
            }
        }
        else {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(725, '{0} hour', value))
                    : ( localize(726, '{0} hr', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(727, '{0} hours', value))
                    : ( localize(728, '{0} hrs', value));
            }
        }
    }
    if (seconds < week) {
        value = Math.floor(seconds / day);
        if (appendAgoLabel) {
            return value === 1
                ? ( localize(729, '{0} day ago', value))
                : ( localize(730, '{0} days ago', value));
        }
        else {
            return value === 1
                ? ( localize(731, '{0} day', value))
                : ( localize(732, '{0} days', value));
        }
    }
    if (seconds < month) {
        value = Math.floor(seconds / week);
        if (appendAgoLabel) {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(733, '{0} week ago', value))
                    : ( localize(734, '{0} wk ago', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(735, '{0} weeks ago', value))
                    : ( localize(736, '{0} wks ago', value));
            }
        }
        else {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(737, '{0} week', value))
                    : ( localize(738, '{0} wk', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(739, '{0} weeks', value))
                    : ( localize(740, '{0} wks', value));
            }
        }
    }
    if (seconds < year) {
        value = Math.floor(seconds / month);
        if (appendAgoLabel) {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(741, '{0} month ago', value))
                    : ( localize(742, '{0} mo ago', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(743, '{0} months ago', value))
                    : ( localize(744, '{0} mos ago', value));
            }
        }
        else {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(745, '{0} month', value))
                    : ( localize(746, '{0} mo', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(747, '{0} months', value))
                    : ( localize(748, '{0} mos', value));
            }
        }
    }
    value = Math.floor(seconds / year);
    if (appendAgoLabel) {
        if (value === 1) {
            return useFullTimeWords
                ? ( localize(749, '{0} year ago', value))
                : ( localize(750, '{0} yr ago', value));
        }
        else {
            return useFullTimeWords
                ? ( localize(751, '{0} years ago', value))
                : ( localize(752, '{0} yrs ago', value));
        }
    }
    else {
        if (value === 1) {
            return useFullTimeWords
                ? ( localize(753, '{0} year', value))
                : ( localize(754, '{0} yr', value));
        }
        else {
            return useFullTimeWords
                ? ( localize(755, '{0} years', value))
                : ( localize(756, '{0} yrs', value));
        }
    }
}
function getDurationString(ms, useFullTimeWords) {
    const seconds = Math.abs(ms / 1000);
    if (seconds < 1) {
        return ( localize(758, '{0}ms', ms));
    }
    if (seconds < minute) {
        return ( localize(760, '{0}s', Math.round(ms) / 1000));
    }
    if (seconds < hour) {
        return ( localize(762, '{0} mins', Math.round(ms / (1000 * minute))));
    }
    if (seconds < day) {
        return ( localize(764, '{0} hrs', Math.round(ms / (1000 * hour))));
    }
    return ( localize(765, '{0} days', Math.round(ms / (1000 * day))));
}
function toLocalISOString(date) {
    return date.getFullYear() +
        '-' + String(date.getMonth() + 1).padStart(2, '0') +
        '-' + String(date.getDate()).padStart(2, '0') +
        'T' + String(date.getHours()).padStart(2, '0') +
        ':' + String(date.getMinutes()).padStart(2, '0') +
        ':' + String(date.getSeconds()).padStart(2, '0') +
        '.' + (date.getMilliseconds() / 1000).toFixed(3).slice(2, 5) +
        'Z';
}
export { fromNow, getDurationString, toLocalISOString };
